@@ -15,7 +15,7 @@ from .__about__ import (
 )
 
 __all__ = [
-    '__copyright__',
-    '__credits__',
-    '__version__',
+    "__copyright__",
+    "__credits__",
+    "__version__",
 ]
